==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/duckie/dialogs_de.lua <==

dialogId("odp-v-kachna", "font_big", "Doesn`t this duck look suspicious to you?")
dialogStr("Findest du nicht, dass diese Ente verdächtig aussieht?")


dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("Ich finde, sie sieht blöd aus.")


dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("Ich finde, sie sieht aufblasbar aus.")


dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Siehst du den Schneemann?")


dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Was meinst du? Schneemänner gehören in die Messe.")


dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Mach mal den Wasserhahn auf!")


dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("Das war mal ein Witz. Hah, hah.")


dialogId("odp-m-predmet", "font_small", "And there isn't even a funny animated object here.")
dialogStr("Hier ist nichtmal ein lustiger animierter Gegenstand.")


dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Aber ein wunderschöner Wellenhintergrund.")


dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Mach weiter, damit wir hier wegkommen.")


dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("Und was ist mit mir?")


dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("Bin ich dir nicht gut genug, oder was?")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/duckie/dialogs_de.lua <==

dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
dialogStr("Findest du nicht, dass diese Ente verdächtig aussieht?")


dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
dialogStr("Ich finde, sie sieht blöd aus.")


dialogId("odp-m-zda1", "font_small", "I think it looks inflatable.")
dialogStr("Ich finde, sie sieht aufblasbar aus.")


dialogId("odp-v-snehulak", "font_big", "Can you see that snowman?")
dialogStr("Siehst du den Schneemann?")


dialogId("odp-m-blaznis", "font_small", "What do you mean? Snowmen belong to the Mess Hall.")
dialogStr("Was meinst du? Schneemänner gehören in die Messe.")


dialogId("odp-m-kohout", "font_small", "Try to open that tap!")
dialogStr("Mach mal den Wasserhahn auf!")


dialogId("odp-v-vtip", "font_big", "Now, this was a joke. Heh, heh.")
dialogStr("Das war mal ein Witz. Hah, hah.")


dialogId("odp-m-predmet", "font_small", "And there isn't even a funny animated object here.")
dialogStr("Hier ist nichtmal ein lustiger animierter Gegenstand.")


dialogId("odp-v-pozadi", "font_big", "But a beautifully wavy background.")
dialogStr("Aber ein wunderschöner Wellenhintergrund.")


dialogId("odp-v-pohni", "font_big", "Move on, so that we can get going.")
dialogStr("Mach weiter, damit wir hier wegkommen.")


dialogId("odp-v-coja", "font_big", "And what about me?")
dialogStr("Und was ist mit mir?")


dialogId("odp-v-nestacim", "font_big", "Am I not enough for you now, or what?")
dialogStr("Bin ich dir nicht gut genug, oder was?")
